searchData={"items":[{"type":"module","title":"ExJSONPointer","doc":"An Elixir implementation of [RFC 6901](https://www.rfc-editor.org/rfc/rfc6901.html) JSON Pointer for locating specific values within JSON documents.","ref":"ExJSONPointer.html"},{"type":"module","title":"Usage - ExJSONPointer","doc":"The JSON pointer string syntax can be represented as a JSON string:\n\n```elixir\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => \"hello\"}}}, \"/a/b/c\")\n\"hello\"\n\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => \"hello\"}}}, \"/a/b\")\n%{\"c\" => \"hello\"}\n\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => [1, 2, 3]}}}, \"/a/b/c\")\n[1, 2, 3]\n\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => [1, 2, 3]}}}, \"/a/b/c/2\")\n3\n\niex> ExJSONPointer.resolve(%{\"a\" => [%{\"b\" => %{\"c\" => [1, 2]}}, 2, 3]}, \"/a/2\")\n3\n\niex> ExJSONPointer.resolve(%{\"a\" => [%{\"b\" => %{\"c\" => [1, 2]}}, 2, 3]}, \"/a/0/b/c/1\")\n2\n```\n\nor a URI fragment identifier:\n\n```elixir\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => \"hello\"}}}, \"#/a/b/c\")\n\"hello\"\n\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => \"hello\"}}}, \"#/a/b\")\n%{\"c\" => \"hello\"}\n\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => [1, 2, 3]}}}, \"#/a/b/c\")\n[1, 2, 3]\n\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => [1, 2, 3]}}}, \"#/a/b/c/2\")\n3\n\niex> ExJSONPointer.resolve(%{\"a\" => [%{\"b\" => %{\"c\" => [1, 2]}}, 2, 3]}, \"#/a/2\")\n3\n\niex> ExJSONPointer.resolve(%{\"a\" => [%{\"b\" => %{\"c\" => [1, 2]}}, 2, 3]}, \"#/a/0/b/c/1\")\n2\n```\n\nSome cases that a JSON pointer that references a nonexistent value:\n\n```elixir\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => \"hello\"}}}, \"/a/b/d\")\n{:error, \"not found\"}\n\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => [1, 2, 3]}}}, \"/a/b/c/4\")\n{:error, \"not found\"}\n\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => \"hello\"}}}, \"#/a/b/d\")\n{:error, \"not found\"}\n\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => [1, 2, 3]}}}, \"#/a/b/c/4\")\n{:error, \"not found\"}\n```\n\nSome cases that a JSON pointer has some empty reference tokens, and link a `$ref` [test case](https://github.com/json-schema-org/JSON-Schema-Test-Suite/blob/main/tests/draft2020-12/ref.json#L1023) from JSON Schema Test Suite(draft 2020-12) for reference.\n\n```elixir\niex> ExJSONPointer.resolve(%{\"\" => %{\"\" => 1}}, \"/\")\n%{\"\" => 1} \n\niex> ExJSONPointer.resolve(%{\"\" => %{\"\" => 1}}, \"//\")\n1\n\niex> ExJSONPointer.resolve(%{\"\" => %{\"\" => 1, \"b\" => %{\"\" => 2}}}, \"//b\")\n%{\"\" => 2}\n\niex> ExJSONPointer.resolve(%{\"\" => %{\"\" => 1, \"b\" => %{\"\" => 2}}}, \"//b/\")\n2\n\niex> ExJSONPointer.resolve(%{\"\" => %{\"\" => 1, \"b\" => %{\"\" => 2}}}, \"//b///\")\n{:error, \"not found\"}\n```\n\nInvalid JSON pointer syntax:\n\n```elixir\niex> ExJSONPointer.resolve(%{\"a\" =>%{\"b\" => %{\"c\" => [1, 2, 3]}}}, \"a/b\")\n{:error, \"invalid pointer syntax\"}\n\niex> ExJSONPointer.resolve(%{\"a\" =>%{\"b\" => %{\"c\" => [1, 2, 3]}}}, \"##/a\")\n{:error, \"invalid pointer syntax\"}\n\n```\n\nPlease see the test cases for more examples.","ref":"ExJSONPointer.html#module-usage"},{"type":"type","title":"ExJSONPointer.document/0","doc":"The JSON document to be processed, must be a map.","ref":"ExJSONPointer.html#t:document/0"},{"type":"type","title":"ExJSONPointer.pointer/0","doc":"The JSON Pointer string that follows RFC 6901 specification.\nCan be either a JSON String Representation (starting with '/') or\na URI Fragment Identifier Representation (starting with '#').","ref":"ExJSONPointer.html#t:pointer/0"},{"type":"function","title":"ExJSONPointer.resolve/2","doc":"Resolve the JSON document with the given JSON Pointer to find the accompanying value.\n\nThe pointer can be either:\n- An empty string (\"\") or \"#\" to reference the whole document\n- A JSON String Representation starting with \"/\"\n- A URI Fragment Identifier Representation starting with \"#\"","ref":"ExJSONPointer.html#resolve/2"},{"type":"function","title":"Examples - ExJSONPointer.resolve/2","doc":"iex> doc = %{\"foo\" => %{\"bar\" => \"baz\"}}\n    iex> ExJSONPointer.resolve(doc, \"/foo/bar\")\n    \"baz\"\n    iex> ExJSONPointer.resolve(doc, \"/foo/baz\")\n    {:error, \"not found\"}\n    iex> ExJSONPointer.resolve(doc, \"##foo\")\n    {:error, \"invalid pointer syntax\"}","ref":"ExJSONPointer.html#resolve/2-examples"},{"type":"type","title":"ExJSONPointer.result/0","doc":"The result of resolving a JSON Pointer:\n* `term()` - the resolved value\n* `{:error, String.t()}` - when there is an error in pointer syntax or value not found","ref":"ExJSONPointer.html#t:result/0"},{"type":"extras","title":"ExJSONPointer","doc":"# ExJSONPointer\n\n[![hex.pm version](https://img.shields.io/hexpm/v/ex_json_pointer.svg?v=1)](https://hex.pm/packages/ex_json_pointer)\n\n<!-- MDOC !-->\n\nAn Elixir implementation of [RFC 6901](https://www.rfc-editor.org/rfc/rfc6901.html) JSON Pointer for locating specific values within JSON documents.","ref":"readme.html"},{"type":"extras","title":"Usage - ExJSONPointer","doc":"The JSON pointer string syntax can be represented as a JSON string:\n\n```elixir\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => \"hello\"}}}, \"/a/b/c\")\n\"hello\"\n\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => \"hello\"}}}, \"/a/b\")\n%{\"c\" => \"hello\"}\n\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => [1, 2, 3]}}}, \"/a/b/c\")\n[1, 2, 3]\n\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => [1, 2, 3]}}}, \"/a/b/c/2\")\n3\n\niex> ExJSONPointer.resolve(%{\"a\" => [%{\"b\" => %{\"c\" => [1, 2]}}, 2, 3]}, \"/a/2\")\n3\n\niex> ExJSONPointer.resolve(%{\"a\" => [%{\"b\" => %{\"c\" => [1, 2]}}, 2, 3]}, \"/a/0/b/c/1\")\n2\n```\n\nor a URI fragment identifier:\n\n```elixir\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => \"hello\"}}}, \"#/a/b/c\")\n\"hello\"\n\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => \"hello\"}}}, \"#/a/b\")\n%{\"c\" => \"hello\"}\n\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => [1, 2, 3]}}}, \"#/a/b/c\")\n[1, 2, 3]\n\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => [1, 2, 3]}}}, \"#/a/b/c/2\")\n3\n\niex> ExJSONPointer.resolve(%{\"a\" => [%{\"b\" => %{\"c\" => [1, 2]}}, 2, 3]}, \"#/a/2\")\n3\n\niex> ExJSONPointer.resolve(%{\"a\" => [%{\"b\" => %{\"c\" => [1, 2]}}, 2, 3]}, \"#/a/0/b/c/1\")\n2\n```\n\nSome cases that a JSON pointer that references a nonexistent value:\n\n```elixir\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => \"hello\"}}}, \"/a/b/d\")\n{:error, \"not found\"}\n\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => [1, 2, 3]}}}, \"/a/b/c/4\")\n{:error, \"not found\"}\n\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => \"hello\"}}}, \"#/a/b/d\")\n{:error, \"not found\"}\n\niex> ExJSONPointer.resolve(%{\"a\" => %{\"b\" => %{\"c\" => [1, 2, 3]}}}, \"#/a/b/c/4\")\n{:error, \"not found\"}\n```\n\nSome cases that a JSON pointer has some empty reference tokens, and link a `$ref` [test case](https://github.com/json-schema-org/JSON-Schema-Test-Suite/blob/main/tests/draft2020-12/ref.json#L1023) from JSON Schema Test Suite(draft 2020-12) for reference.\n\n```elixir\niex> ExJSONPointer.resolve(%{\"\" => %{\"\" => 1}}, \"/\")\n%{\"\" => 1} \n\niex> ExJSONPointer.resolve(%{\"\" => %{\"\" => 1}}, \"//\")\n1\n\niex> ExJSONPointer.resolve(%{\"\" => %{\"\" => 1, \"b\" => %{\"\" => 2}}}, \"//b\")\n%{\"\" => 2}\n\niex> ExJSONPointer.resolve(%{\"\" => %{\"\" => 1, \"b\" => %{\"\" => 2}}}, \"//b/\")\n2\n\niex> ExJSONPointer.resolve(%{\"\" => %{\"\" => 1, \"b\" => %{\"\" => 2}}}, \"//b///\")\n{:error, \"not found\"}\n```\n\nInvalid JSON pointer syntax:\n\n```elixir\niex> ExJSONPointer.resolve(%{\"a\" =>%{\"b\" => %{\"c\" => [1, 2, 3]}}}, \"a/b\")\n{:error, \"invalid pointer syntax\"}\n\niex> ExJSONPointer.resolve(%{\"a\" =>%{\"b\" => %{\"c\" => [1, 2, 3]}}}, \"##/a\")\n{:error, \"invalid pointer syntax\"}\n\n```\n\nPlease see the test cases for more examples.","ref":"readme.html#usage"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.1"}}